summaryrefslogtreecommitdiffhomepage
path: root/frameworks
diff options
context:
space:
mode:
authorAmlal El Mahrouss <amlal@nekernel.org>2026-04-01 07:49:40 +0200
committerAmlal El Mahrouss <amlal@nekernel.org>2026-04-01 07:49:40 +0200
commit8424c663dd9ff9479f80e3d3fdfc5534942c3c32 (patch)
tree56c8e08d298e98b796db6007915b432a989ad489 /frameworks
parent692165bf082e17aef6558519a4cb488de7e05435 (diff)
[CHORE] Reworking X11 server architecture.
Signed-off-by: Amlal El Mahrouss <amlal@nekernel.org>
Diffstat (limited to 'frameworks')
-rw-r--r--frameworks/libSocket.fwrk/dist/.keep0
-rw-r--r--frameworks/libSocket.fwrk/headers/Config.h18
-rw-r--r--frameworks/libSocket.fwrk/libSocket.fwrk.json20
-rw-r--r--frameworks/libSocket.fwrk/src/.keep0
-rw-r--r--frameworks/libSocket.fwrk/xml/app.xml4
-rw-r--r--frameworks/libX11.fwrk/headers/Foundation.hpp (renamed from frameworks/libX11.fwrk/headers/Config.h)26
-rw-r--r--frameworks/libX11.fwrk/src/Foundation+X11.cpp (renamed from frameworks/libX11.fwrk/src/X11ConnMgr.cpp)6
7 files changed, 18 insertions, 56 deletions
diff --git a/frameworks/libSocket.fwrk/dist/.keep b/frameworks/libSocket.fwrk/dist/.keep
deleted file mode 100644
index e69de29..0000000
--- a/frameworks/libSocket.fwrk/dist/.keep
+++ /dev/null
diff --git a/frameworks/libSocket.fwrk/headers/Config.h b/frameworks/libSocket.fwrk/headers/Config.h
deleted file mode 100644
index 7cde306..0000000
--- a/frameworks/libSocket.fwrk/headers/Config.h
+++ /dev/null
@@ -1,18 +0,0 @@
-// SPDX-License-Identifier: Apache-2.0
-// Copyright 2026, Amlal El Mahrouss (amlal@nekernel.org)
-// Licensed under the Apache License, Version 2.0 (see LICENSE file)
-// Official repository: https://github.com/ne-foss-org/ne-system
-
-#ifndef SOCKET_FOUNDATION_H
-#define SOCKET_FOUNDATION_H
-
-#include <libSystem/SystemKit/System.h>
-
-#define LIBSOCKET_VERSION 0x100000
-
-#define LIBSOCKET_SOCKET_ARRAY_CHECK(PTR) PTR != nullptr
-#define LIBSOCKET_SOCKET_ARRAY_INDEX(ARR, PTR, LEN) ARR[((SInt64) PTR) % LEN]
-
-#define LIBSOCKET_SOCKET_INVALID ((SizeT)-1)
-
-#endif
diff --git a/frameworks/libSocket.fwrk/libSocket.fwrk.json b/frameworks/libSocket.fwrk/libSocket.fwrk.json
deleted file mode 100644
index a1b13bb..0000000
--- a/frameworks/libSocket.fwrk/libSocket.fwrk.json
+++ /dev/null
@@ -1,20 +0,0 @@
-{
- "compiler_path": "x86_64-w64-mingw32-g++",
- "compiler_std": "c++20",
- "headers_path": ["../", "./", "../../src/kernel", "../../src/kernel/src"],
- "sources_path": ["src/*.cpp"],
- "output_name": "./dist/libSocket.fwrk.dylib",
- "compiler_flags": [
- "-ffreestanding",
- "-shared",
- "-fno-rtti",
- "-fno-exceptions",
- "-Wl,--subsystem=17"
- ],
- "cpp_macros": [
- "kSocketVersion=0x0100",
- "kSocketVersionHighest=0x0100",
- "kSocketVersionLowest=0x0100"
- ]
- }
-
diff --git a/frameworks/libSocket.fwrk/src/.keep b/frameworks/libSocket.fwrk/src/.keep
deleted file mode 100644
index e69de29..0000000
--- a/frameworks/libSocket.fwrk/src/.keep
+++ /dev/null
diff --git a/frameworks/libSocket.fwrk/xml/app.xml b/frameworks/libSocket.fwrk/xml/app.xml
deleted file mode 100644
index bd1dbee..0000000
--- a/frameworks/libSocket.fwrk/xml/app.xml
+++ /dev/null
@@ -1,4 +0,0 @@
-<PropertyList>
-<PLEntry Type="CFString" Name="LibraryName" Len="3" Value="Socket" />
-<PLEntry Type="BOOL" Name="CacheLibs" Value="YES" />
-</PropertyList> \ No newline at end of file
diff --git a/frameworks/libX11.fwrk/src/X11ConnMgr.cpp b/frameworks/libX11.fwrk/src/Foundation+X11.cpp
index ca55c8b..37e2920 100644
--- a/frameworks/libX11.fwrk/src/X11ConnMgr.cpp
+++ b/frameworks/libX11.fwrk/src/Foundation+X11.cpp
@@ -3,20 +3,20 @@
// Licensed under the Apache License, Version 2.0 (see LICENSE file)
// Official repository: https://github.com/ne-foss-org/ne-system
-#include <libX11.fwrk/headers/Config.h>
+#include <libX11.fwrk/headers/Foundation.hpp>
namespace X11 {
namespace Detail {
- static X11ConnectionPtr X11MakeConnection() {
+ X11ConnectionPtr x11_make_connection_ptr() {
auto ptr = new X11Connection{};
if (!ptr) return nullptr;
return ptr;
}
- static Void X11DeleteConnection(X11ConnectionPtr ptr) {
+ Void x11_delete_connection_ptr(X11ConnectionPtr ptr) {
if (!ptr) return;
delete ptr;
diff --git a/frameworks/libX11.fwrk/headers/Config.h b/frameworks/libX11.fwrk/headers/Foundation.hpp
index 44abc06..18d119d 100644
--- a/frameworks/libX11.fwrk/headers/Config.h
+++ b/frameworks/libX11.fwrk/headers/Foundation.hpp
@@ -3,8 +3,8 @@
// Licensed under the Apache License, Version 2.0 (see LICENSE file)
// Official repository: https://github.com/ne-foss-org/ne-system
-#ifndef X11_FOUNDATION_H
-#define X11_FOUNDATION_H
+#ifndef LIBX11_FOUNDATION_HPP
+#define LIBX11_FOUNDATION_HPP
#include <libSystem/SystemKit/System.h>
@@ -15,16 +15,20 @@
namespace X11 {
-/// @brief Plain Old Data type for a X11 connection.
-struct X11Connection final {
- SInt32 fSocket;
- SInt32 fType;
- SInt32 fFlags;
- SInt32 fPad;
-};
+namespace Detail {
-typedef X11Connection* X11ConnectionPtr;
-typedef X11ConnectionPtr* X11ConnectionArray;
+ /// @brief Plain Old Data type for a X11 connection.
+ struct X11Connection final {
+ SInt32 fSocket;
+ SInt32 fType;
+ SInt32 fFlags;
+ SInt32 fPad;
+ };
+
+ typedef X11Connection* X11ConnectionPtr;
+ typedef X11ConnectionPtr* X11ConnectionArray;
+
+} // namespace Detail
} // namespace X11